# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from .safety_check_report import SafetyCheckReport


class BotLogicSafetyItem(UniversalBaseModel):
    safety_check_passed: typing_extensions.Annotated[bool, FieldMetadata(alias="safetyCheckPassed")]
    report: typing.Optional[SafetyCheckReport] = pydantic.Field(default=None)
    """
    If the safety check failed, this contains more details about the failure.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .agent_audio_chunk import AgentAudioChunk
from .agent_transcript import AgentTranscript
from .audio_format import AudioFormat
from .config import Config
from .conversation_ended import ConversationEnded
from .conversation_ready import ConversationReady
from .error import Error
from .server_event_base import ServerEventBase
from .user_audio_chunk import UserAudioChunk
from .user_finished_speaking import UserFinishedSpeaking
from .user_started_speaking import UserStartedSpeaking
from .user_transcript import UserTranscript

__all__ = [
    "AgentAudioChunk",
    "AgentTranscript",
    "AudioFormat",
    "Config",
    "ConversationEnded",
    "ConversationReady",
    "Error",
    "ServerEventBase",
    "UserAudioChunk",
    "UserFinishedSpeaking",
    "UserStartedSpeaking",
    "UserTranscript",
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    AgentAudioChunk,
    AgentTranscript,
    AudioFormat,
    Config,
    ConversationEnded,
    ConversationReady,
    Error,
    ServerEventBase,
    UserAudioChunk,
    UserFinishedSpeaking,
    UserStartedSpeaking,
    UserTranscript,
)

__all__ = [
    "AgentAudioChunk",
    "AgentTranscript",
    "AudioFormat",
    "Config",
    "ConversationEnded",
    "ConversationReady",
    "Error",
    "ServerEventBase",
    "UserAudioChunk",
    "UserFinishedSpeaking",
    "UserStartedSpeaking",
    "UserTranscript",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...commons.types.base_paginated_request import BasePaginatedRequest
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from .customer_field import CustomerField
from .customer_filter import CustomerFilter


class CustomersSearchRequest(BasePaginatedRequest):
    sort: typing.Optional[CustomerField] = pydantic.Field(default=None)
    """
    The field to sort by, defaults to created timestamp
    """

    filter: typing.Optional[CustomerFilter] = pydantic.Field(default=None)
    """
    The filter to apply to the customers.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

EventField = typing.Union[
    typing.Literal[
        "CREATED_AT",
        "EVENT_NAME",
        "EVENT_TYPE",
        "APP",
        "SESSION_ID",
        "SOURCE_TYPE",
        "SOURCE_LANGUAGE_CODE",
        "SOURCE_DEVICE_TYPE",
        "SOURCE_DEVICE_NAME",
        "SOURCE_BROWSER_TYPE",
        "SOURCE_BROWSER_NAME",
        "SOURCE_GEO_CITY",
        "SOURCE_GEO_STATE",
        "SOURCE_GEO_COUNTRY",
        "USER_REFERENCE_ID",
        "AGENT_USER_ID",
        "TIMESTAMP",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from .event_response import EventResponse
from .page import Page


class EventsSearchResponse(Page):
    events: typing.List[EventResponse] = pydantic.Field()
    """
    The list of events
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    CustomerBase,
    CustomerField,
    CustomerFilter,
    CustomerPatchRequest,
    CustomerRequest,
    CustomerResponse,
    CustomerStatus,
    CustomersSearchRequest,
    CustomersSearchResponse,
)

__all__ = [
    "CustomerBase",
    "CustomerField",
    "CustomerFilter",
    "CustomerPatchRequest",
    "CustomerRequest",
    "CustomerResponse",
    "CustomerStatus",
    "CustomersSearchRequest",
    "CustomersSearchResponse",
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import SessionTokenRequest, SessionTokenResponse

__all__ = ["SessionTokenRequest", "SessionTokenResponse"]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.serialization import FieldMetadata
from .event_base_no_id import EventBaseNoId
from .system_event_name import SystemEventName


class NovelSystemEventNoId(EventBaseNoId):
    event_name: typing_extensions.Annotated[SystemEventName, FieldMetadata(alias="eventName")] = pydantic.Field()
    """
    The name of the event
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...commons.types.entity_id_without_agent import EntityIdWithoutAgent
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from .conversation_message_request import ConversationMessageRequest


class DeliverConversationMessageRequest(UniversalBaseModel):
    conversation_id: typing_extensions.Annotated[EntityIdWithoutAgent, FieldMetadata(alias="conversationId")] = (
        pydantic.Field()
    )
    """
    The ID of the conversation to deliver the message to. Message delivery will fail if the conversation does not have the `ASYNC` capability or if it is not `open`.
    """

    message: ConversationMessageRequest = pydantic.Field()
    """
    The message to deliver.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .session_token_request import SessionTokenRequest
from .session_token_response import SessionTokenResponse

__all__ = ["SessionTokenRequest", "SessionTokenResponse"]



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from .raw_client import AsyncRawAuthClient, RawAuthClient
from .types.session_token_response import SessionTokenResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class AuthClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawAuthClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawAuthClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawAuthClient
        """
        return self._raw_client

    def session_token(
        self, *, ttl_seconds: int, request_options: typing.Optional[RequestOptions] = None
    ) -> SessionTokenResponse:
        """
        Creates a short-lived session token that can be used to authenticate
        WebSocket connections. Session tokens are useful for client-side applications where
        you don’t want to expose your API key.

        Parameters
        ----------
        ttl_seconds : int

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SessionTokenResponse

        Examples
        --------
        from mavenagi import MavenAGI

        client = MavenAGI(
            organization_id="YOUR_ORGANIZATION_ID",
            agent_id="YOUR_AGENT_ID",
            app_id="YOUR_APP_ID",
            app_secret="YOUR_APP_SECRET",
        )
        client.auth.session_token(
            ttl_seconds=3600,
        )
        """
        _response = self._raw_client.session_token(ttl_seconds=ttl_seconds, request_options=request_options)
        return _response.data


class AsyncAuthClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawAuthClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawAuthClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawAuthClient
        """
        return self._raw_client

    async def session_token(
        self, *, ttl_seconds: int, request_options: typing.Optional[RequestOptions] = None
    ) -> SessionTokenResponse:
        """
        Creates a short-lived session token that can be used to authenticate
        WebSocket connections. Session tokens are useful for client-side applications where
        you don’t want to expose your API key.

        Parameters
        ----------
        ttl_seconds : int

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SessionTokenResponse

        Examples
        --------
        import asyncio

        from mavenagi import AsyncMavenAGI

        client = AsyncMavenAGI(
            organization_id="YOUR_ORGANIZATION_ID",
            agent_id="YOUR_AGENT_ID",
            app_id="YOUR_APP_ID",
            app_secret="YOUR_APP_SECRET",
        )


        async def main() -> None:
            await client.auth.session_token(
                ttl_seconds=3600,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.session_token(ttl_seconds=ttl_seconds, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

ActionParameterType = typing.Union[
    typing.Literal[
        "STRING",
        "MULTILINE",
        "BOOLEAN",
        "NUMBER",
        "DATETIME",
        "DATE",
        "TIME",
        "EMAIL",
        "PHONE",
        "SCHEMA",
        "FILE",
        "OAUTH",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from .audio_format import AudioFormat


class Config(UniversalBaseModel):
    """
    Initialize conversation with configuration parameters
    """

    type: typing.Literal["config"] = "config"
    input_format: typing_extensions.Annotated[AudioFormat, FieldMetadata(alias="inputFormat")] = pydantic.Field()
    """
    The user text to send into the conversation.
    """

    output_format: typing_extensions.Annotated[AudioFormat, FieldMetadata(alias="outputFormat")] = pydantic.Field()
    """
    The user text to send into the conversation.
    """

    conversation_id: typing_extensions.Annotated[str, FieldMetadata(alias="conversationId")] = pydantic.Field()
    """
    The conversation ID which was created prior to starting this conversation.
    """

    app_id: typing_extensions.Annotated[str, FieldMetadata(alias="appId")] = pydantic.Field()
    """
    The app ID this conversation ID is associated with.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from .action_properties import ActionProperties


class ActionBase(ActionProperties):
    name: str = pydantic.Field()
    """
    The name of the action. This is displayed to the end user as part of forms when user interaction is required. It is also used to help Maven decide if the action is relevant to a conversation.
    """

    description: str = pydantic.Field()
    """
    The description of the action. Must be less than 1024 characters. This helps Maven decide if the action is relevant to a conversation and is not displayed directly to the end user. Descriptions are used by the LLM.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .precondition_group import PreconditionGroup  # noqa: E402, F401, I001



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from .entity_id_without_agent import EntityIdWithoutAgent


class DocumentInformation(UniversalBaseModel):
    knowledge_base_id: typing_extensions.Annotated[EntityIdWithoutAgent, FieldMetadata(alias="knowledgeBaseId")] = (
        pydantic.Field()
    )
    """
    Unique identifier for the knowledge base.
    """

    document_id: typing_extensions.Annotated[EntityIdWithoutAgent, FieldMetadata(alias="documentId")] = pydantic.Field()
    """
    Unique identifier for the document.
    """

    title: typing.Optional[str] = pydantic.Field(default=None)
    """
    Title of the document.
    """

    snippet: typing.Optional[str] = pydantic.Field(default=None)
    """
    Snippet or summary of the document.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.serialization import FieldMetadata
from .event_analytics_request import EventAnalyticsRequest
from .event_group_by import EventGroupBy
from .event_metric import EventMetric


class EventBarChartRequest(EventAnalyticsRequest):
    bar_definition: typing_extensions.Annotated[EventGroupBy, FieldMetadata(alias="barDefinition")] = pydantic.Field()
    """
    Determines how data is grouped along the x-axis. Each unique value forms a separate bar.
    """

    metric: EventMetric = pydantic.Field()
    """
    Metric defining the y-axis values for the bar chart.
    """

    vertical_grouping: typing_extensions.Annotated[
        typing.Optional[EventGroupBy], FieldMetadata(alias="verticalGrouping")
    ] = pydantic.Field(default=None)
    """
    Optionally defines vertical grouping within each bar, producing multiple series.
    If omitted, a single series is generated.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...commons.types.entity_id import EntityId
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.serialization import FieldMetadata
from .customer_base import CustomerBase


class CustomerResponse(CustomerBase):
    """
    Examples
    --------
    from mavenagi.commons import EntityId
    from mavenagi.customers import CustomerResponse

    CustomerResponse(
        customer_id=EntityId(
            reference_id="acme",
            app_id="customer-app",
            organization_id="acme",
            agent_id="support",
            type="CUSTOMER",
        ),
        name="Acme Corporation",
        status="ACTIVE",
        description="Acme is a company that makes widgets",
        metadata={
            "industry": "widget manufacturing",
            "initial-note": "Acme is a great company",
        },
        assignees=[],
        members=[],
    )
    """

    customer_id: typing_extensions.Annotated[EntityId, FieldMetadata(alias="customerId")] = pydantic.Field()
    """
    ID that uniquely identifies this customer
    """

    assignees: typing.Set[str] = pydantic.Field()
    """
    Set of agent user IDs assigned to this customer
    """

    members: typing.Set[str] = pydantic.Field()
    """
    Set of agent user IDs who are members of this customer
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...commons.types.page import Page
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from .customer_response import CustomerResponse


class CustomersSearchResponse(Page):
    customers: typing.List[CustomerResponse]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
